"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomStrategy = void 0;
const strategy_1 = require("../strategy");
/**
 * The custom authentication strategy authenticates requests based on a
 * function callback.
 * Applications must supply a `verify` callback which executes custom
 * authentication logic, and then returns a `user`, if the user can't be
 * provided or an exception occurred an error must be thorwn.
 *
 * @example
 * authenticator.use(new CustomStrategy(
 *   (request, sessionStorage) => {
 *     return User.findOne({ username: req.body.username });
 *   }
 * ));
 */
class CustomStrategy extends strategy_1.Strategy {
    constructor() {
        super(...arguments);
        this.name = "custom";
    }
    authenticate(request, sessionStorage, options) {
        return this.verify({ request, sessionStorage, options });
    }
}
exports.CustomStrategy = CustomStrategy;
